vfbLib.parsers.glyph.GlyphOriginParser
======================================

.. currentmodule:: vfbLib.parsers.glyph

.. autoclass:: GlyphOriginParser
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~GlyphOriginParser.__init__
      ~GlyphOriginParser.parse
      ~GlyphOriginParser.parse_hex
      ~GlyphOriginParser.read_double
      ~GlyphOriginParser.read_doubles
      ~GlyphOriginParser.read_float
      ~GlyphOriginParser.read_floats
      ~GlyphOriginParser.read_int16
      ~GlyphOriginParser.read_int32
      ~GlyphOriginParser.read_int8
      ~GlyphOriginParser.read_str
      ~GlyphOriginParser.read_str_all
      ~GlyphOriginParser.read_uint16
      ~GlyphOriginParser.read_uint32
      ~GlyphOriginParser.read_uint8
      ~GlyphOriginParser.read_value
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~GlyphOriginParser.encoding
      ~GlyphOriginParser.master_count
      ~GlyphOriginParser.stream
      ~GlyphOriginParser.ttStemsH_count
      ~GlyphOriginParser.ttStemsV_count
   
   